@@ -1,7 +1,7 @@
 import argparse
 import os
 
-parser = argparse.ArgumentParser(description='A command line function tester',epilog="Usage example: litio adding.py --function add --params number1 200 int number2 300 int")
+parser = argparse.ArgumentParser(description='A command line function tester',epilog="Usage example: litio adding.py --function add --function-type function --params number1 200 int number2 300 int")
 parser.add_argument('file', metavar='file', type=str, help='file to execute')
 parser.add_argument('--function',"-f",default="", help='function to execute',required=True)
 parser.add_argument("--function-type","-t",dest="function_type",choices=("function","method","classmethod"),help='function type',required=True)
@@ -33,8 +33,9 @@ def extract_args(params: dict) -> str:
         arguments += key + "=" + str(value["value"]) + (", " if key != list(params.keys())[-1] else "")
     return arguments
 def litio():
+    directory = os.path.join(os.getcwd(),args.file).replace("\\","/")
     exec("import importlib.util;" + \
-    f"spec = importlib.util.spec_from_file_location('{args.file.replace('.py','')}','{os.path.join(os.getcwd(),args.file)}');" + \
+    f"spec = importlib.util.spec_from_file_location('{args.file.replace('.py','')}','{directory}');" + \
     "lib = importlib.util.module_from_spec(spec);" + \
     "spec.loader.exec_module(lib);")
     
